@@ -162,10 +162,14 @@ static unibi_term *from_dirs(const char *list, const char *term) {
         z = strchr(a, ':');
 
         ut = from_dir(a, z, NULL, term);
-        if (ut || errno != ENOENT) {
+        if (ut) {
             return ut;
         }
 
+        if (errno != ENOENT && errno != EPERM && errno != EACCES) {
+            return NULL;
+        }
+
         if (!z) {
             break;
         }
@@ -196,9 +200,14 @@ unibi_term *unibi_from_term(const char *term) {
 
     if ((env = getenv("HOME"))) {
         ut = from_dir(env, NULL, ".terminfo", term);
-        if (ut || errno != ENOENT) {
+
+        if (ut) {
             return ut;
         }
+
+        if (errno != ENOENT && errno != EPERM && errno != EACCES) {
+            return NULL;
+        }
     }
 
     if ((env = getenv("TERMINFO_DIRS"))) {
